@@ -82,6 +82,7 @@ Out of the box implementation of the Construct without any override will set the
 * Enable server-side encryption for DynamoDB Table using AWS managed KMS Key
 * Creates a partition key called 'id' for DynamoDB Table
 * Retain the Table when deleting the CloudFormation stack
+* Enable continuous backups and point-in-time recovery
 
 ### AWS Lambda Function
 
@@ -125,9 +126,7 @@ class DynamoDBStreamToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        dynamo_event_source_props: typing.Optional[
-            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
-        ] = None,
+        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
@@ -185,9 +184,7 @@ class DynamoDBStreamToLambdaProps:
     def __init__(
         self,
         *,
-        dynamo_event_source_props: typing.Optional[
-            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
-        ] = None,
+        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
@@ -204,15 +201,11 @@ class DynamoDBStreamToLambdaProps:
         :summary:: The properties for the DynamoDBStreamToLambda Construct
         """
         if isinstance(dynamo_event_source_props, dict):
-            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(
-                **dynamo_event_source_props
-            )
+            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {}
         if dynamo_event_source_props is not None:
             self._values["dynamo_event_source_props"] = dynamo_event_source_props
